{% extends "jmbo/inclusion_tags/modelbase_detail.html" %}

{% block content %}
    <div class="image">
        <img src="{{ object.image_detail_url }}" />
    </div>
    <div class="content">
        {{ object.content|safe }}
    </div>
{% endblock %}
